package sialocacao.professor.database;

import java.util.ArrayList;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import sialocacao.Database;
import sialocacao.SIAlocacaoException;
import sialocacao.professor.Professor;
import sialocacao.professor.fachada.IRegistroProfessores;
import sialocacao.professor.excecoes.ProfessorInexistenteException;

/**
 * <p>Title: SIAlocacao</p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: </p>
 * @author fabrica3
 * @version 1.0
 */

 /**
  * Esta classe implementa a camada de persistencia de professores.
  */
public class ProfessoresDatabase extends Database
  implements IRegistroProfessores{

  public ProfessoresDatabase() throws ClassNotFoundException{
    super();
  }

  public ProfessoresDatabase(String driver, String url, String user,
    String password) throws ClassNotFoundException, IllegalArgumentException{

    super(driver, url, user, password);
  }

  public void inserirProfessor(String name, String area)
    throws SIAlocacaoException{

    try{
      openConnection();

      PreparedStatement cmd =
        getConnection().prepareStatement("INSERT INTO professor (name,"+
        "area) VALUES (?, ?)");

      cmd.setString(1, name);
      cmd.setString(2, area);

      cmd.executeUpdate();

      commit();
    }catch(Exception e){
       throw new SIAlocacaoException(e.getMessage(), e);
     }
     finally{
       try{ if(getConnection() != null) closeConnection(); }
        catch(Exception e){  throw new SIAlocacaoException(e.getMessage(), e); }
     }
  }

  public void alterarProfessor(Professor professor)
    throws SIAlocacaoException, ProfessorInexistenteException{

    try{
      openConnection();

      PreparedStatement cmd =
        getConnection().prepareStatement("UPDATE professor SET name=?, area=? "+
        "WHERE codigo=?");

      cmd.setString(1, professor.getName());
      cmd.setString(2, professor.getArea());
      cmd.setInt(3, professor.getCodigo());

      int num = cmd.executeUpdate();

      if(num == 0){
        throw new ProfessorInexistenteException(professor.getCodigo());
      }

      commit();
    }catch(ProfessorInexistenteException e){
       throw e;
     }
     catch(Exception e){
       throw new SIAlocacaoException(e.getMessage(), e);
     }
     finally{
       try{ if(getConnection() != null) closeConnection(); }
        catch(Exception e){  throw new SIAlocacaoException(e.getMessage(), e); }
     }
  }

  public void excluirProfessor(int codigo)
    throws SIAlocacaoException, ProfessorInexistenteException{

    try{
      openConnection();

      PreparedStatement cmd =
        getConnection().prepareStatement("DELETE FROM professor WHERE "+
        "codigo=?");

      cmd.setInt(1, codigo);

      int num = cmd.executeUpdate();

      if(num == 0){
        throw new ProfessorInexistenteException(codigo);
      }

      commit();
    }catch(ProfessorInexistenteException e){
       throw e;
     }
     catch(Exception e){
       throw new SIAlocacaoException(e.getMessage(), e);
     }
     finally{
       try{ if(getConnection() != null) closeConnection(); }
        catch(Exception e){  throw new SIAlocacaoException(e.getMessage(), e); }
     }
  }

  public Professor buscarProfessor(int codigo)
    throws SIAlocacaoException, ProfessorInexistenteException{

    try{
      openConnection();

      PreparedStatement cmd =
        getConnection().prepareStatement("SELECT name, area FROM professor "+
        "WHERE codigo=?");

      cmd.setInt(1, codigo);

      ResultSet result = cmd.executeQuery();

      Professor professor;

      if(result.next()){
        professor =
          new Professor(codigo,
                        result.getString("name"),
                        result.getString("area"));
      }else{
         throw new ProfessorInexistenteException(codigo);
       }

      commit();

      return professor;
    }catch(ProfessorInexistenteException e){
       throw e;
     }
     catch(Exception e){
       throw new SIAlocacaoException(e.getMessage(), e);
     }
     finally{
       try{ if(getConnection() != null) closeConnection(); }
        catch(Exception e){  throw new SIAlocacaoException(e.getMessage(), e); }
     }
  }

  public ArrayList listarProfessores()
    throws SIAlocacaoException{

    try{
      openConnection();

      PreparedStatement cmd =
        getConnection().prepareStatement("SELECT * FROM professor");

      ResultSet result = cmd.executeQuery();

      ArrayList professores =
        new ArrayList();

      while(result.next()){
        professores.add(
          new Professor(result.getInt("codigo"),
                        result.getString("name"),
                        result.getString("area"))
        );
      }

      commit();

      return professores;
    }catch(Exception e){
       throw new SIAlocacaoException(e.getMessage(), e);
     }
     finally{
       try{ if(getConnection() != null) closeConnection(); }
        catch(Exception e){  throw new SIAlocacaoException(e.getMessage(), e); }
     }
  }
}