package sialocacao;

/**
 * <p>Title: Database.java </p>
 * <p>Description: Respons\uFFFDvel pelo controle de conex\uFFFDo com o banco de dados. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: F\uFFFDbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          F\uFFFDbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da N\uFFFDbrega Medeiros
 * @version 1.0
 */

import java.sql.*;

public class Database {

  /*
   * Guarda conex\uFFFDo com o BD.
   */
  private Connection connection;

  /*
   * Driver do BD.
   */
  private String driver = "org.postgresql.Driver";
  //private String driver = "sun.jdbc.odbc.JdbcOdbcDriver";

  /*
   * URL para acessar o BD.
   */
  private String url = "jdbc:postgresql://localhost/sialocacao";
  //private String url = "jdbc:odbc:sialocacao";

  /*
   * Usu\uFFFDrio para acessar o BD.
   */
  private String user = "lecl";
  //private String user = "";

  /*
   * Senha para acessar o BD.
   */
  private String password = "C1s0Pr&";
  //private String password = "";

  /**
   * Construtor para carregar driver jdbc.
   */
  public Database() throws ClassNotFoundException {
    Class.forName(driver);
  }

  /**
   * Construtor para definir driver, url, usu\uFFFDrio e senha,
   * e carregar driver jdbc.
   */
  public Database(String driver, String url, String user, String password) throws
      ClassNotFoundException, IllegalArgumentException {

    setDriver(driver);
    setUrl(url);
    setUser(user);
    setPassword(password);

    Class.forName(driver);
  }

  /**
   * Pega a conex\uFFFDo corrente.
   * @return connection
   */
  public Connection getConnection() {
    return this.connection;
  }

  /**
   * Define conex\uFFFDo com o BD.
   * @param connection
   */
  public void setConnection(Connection connection) throws
      IllegalArgumentException {

    if (connection == null) {
      throw new IllegalArgumentException("connection == null");
    }

    this.connection = connection;
  }

  /**
   * Pega o driver corrente.
   * @return String
   */
  public String getDriver() {
    return this.driver;
  }

  /**
   * Define driver para do BD.
   * @param driver
   */
  public void setDriver(String driver) throws IllegalArgumentException {

    if (driver == null) {
      throw new IllegalArgumentException("driver == null");
    }

    this.driver = driver;
  }

  /**
   * Pega a url corrente para acessar o BD.
   * @return String
   */
  public String getUrl() {
    return this.url;
  }

  /**
   * Define url para acessar o BD.
   * @param url
   */
  public void setUrl(String url) throws IllegalArgumentException {

    if (url == null) {
      throw new IllegalArgumentException("url == null");
    }
  }

  /**
   * Pega usu\uFFFDrio para acessar o BD.
   * @return String
   */
  public String getUser() {
    return this.user;
  }

  /**
   * Define usu\uFFFDrio para acessar o BD.
   * @param user
   */
  public void setUser(String user) throws IllegalArgumentException {

    if (user == null) {
      throw new IllegalArgumentException("user == null");
    }

    this.user = user;
  }

  /**
   * Pega senha para acessar o BD.
   * @return String
   */
  public String getPassword(String password) {
    return this.password;
  }

  /**
   * Define senha para acessar o BD.
   * @param user
   */
  public void setPassword(String password) throws IllegalArgumentException {

    if (password == null) {
      throw new IllegalArgumentException("user == null");
    }

    this.password = password;
  }

  /**
   * Abre uma conexao com o BD.
   */
  public void openConnection() throws SQLException {

    this.connection = DriverManager.getConnection(url, user, password);

    connection.setAutoCommit(false);
  }

  /**
   * Fecha uma conexao com o BD. Se a conexao nao tiver sido aberta, i.e.
   * connection == null, eh levantada NullPointerException
   */
  public void closeConnection() throws NullPointerException, SQLException {

    if (this.connection == null) {
      throw new NullPointerException("connection == null");
    }

    connection.close();
  }

  /**
   * Efetivar a transa\uFFFD\uFFFDo corrente.
   */
  protected void commit() throws NullPointerException, SQLException {

    if (this.connection == null) {
      throw new NullPointerException("connection == null");
    }

    connection.commit();
  }

  /**
   * Voltar para um estado concistente.
   */
  protected void rollback() throws NullPointerException, SQLException {

    if (this.connection == null) {
      throw new NullPointerException("connection == null");
    }

    connection.rollback();
  }
}