package sialocacao;

/**
 * <p>Title: SIAlocacao.java </p>
 * <p>Description: Responsvel pelo controle do sistema. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.professor.*;
import sialocacao.professor.excecoes.*;
import sialocacao.professor.negocio.*;

import sialocacao.disciplina.*;
import sialocacao.disciplina.excecoes.*;
import sialocacao.disciplina.negocio.*;

import sialocacao.sala.*;
import sialocacao.sala.excecoes.*;
import sialocacao.sala.negocio.*;

import sialocacao.horario.*;
import sialocacao.horario.excecoes.*;
import sialocacao.horario.negocio.*;

import sialocacao.alocacao.*;
import sialocacao.alocacao.excecoes.*;
import sialocacao.alocacao.negocio.*;


public class SIAlocacao {

  /*
   * Cadastro de profesores.
   */
  private ICadastroProfessores cadastroProfessores;

  /*
   * Cadastro de disciplinas.
   */
  private ICadastroDisciplinas cadastroDisciplinas;

  /*
   * Cadastro de salas.
   */
  private ICadastroSalas cadastroSalas;

  /*
   * Cadastro de horrios.
   */
  private ICadastroHorarios cadastroHorarios;

  /*
   * Interface para realizar de alocacoes.
   */
  private IAlocacaoNegocio alocacaoNegocio;

  /*
   * Construtor default responsvel por instanciar os cadastros do sistema.
   */
  public SIAlocacao() throws ClassNotFoundException{

    setCadastroProfessores(new CadastroProfessores());
    setCadastroDisciplinas(new CadastroDisciplinas());
    setCadastroSalas(new CadastroSalas());
    setCadastroHorarios(new CadastroHorarios());
    setAlocacaoNegocio(new AlocacaoNegocio());
  }

  /*
   * Construtor responsvel por instanciar os cadastros do sistema.
   */
  public SIAlocacao(ICadastroProfessores cadastroProfessores,
                    ICadastroDisciplinas cadastroDisciplinas,
                    ICadastroSalas cadastroSalas,
                    ICadastroHorarios cadastroHorarios,
                    IAlocacaoNegocio alocacaoNegocio) {

    setCadastroProfessores(cadastroProfessores);
    setCadastroDisciplinas(cadastroDisciplinas);
    setCadastroSalas(cadastroSalas);
    setCadastroHorarios(cadastroHorarios);
    setAlocacaoNegocio(alocacaoNegocio);
  }

  /**
   * Define cadastro de professores.
   * @param cadastroProfessores
   */
  public void setCadastroProfessores(ICadastroProfessores cadastroProfessores) throws
      IllegalArgumentException {

    if (cadastroProfessores == null) {
      throw new IllegalArgumentException("cadastroProfessores == null");
    }
    this.cadastroProfessores = cadastroProfessores;
  }

  /**
   * Define cadastro de disciplinas.
   * @param cadastroDisciplinas
   */
  public void setCadastroDisciplinas(ICadastroDisciplinas cadastroDisciplinas) throws
    IllegalArgumentException {

    if (cadastroDisciplinas == null) {
      throw new IllegalArgumentException("cadastroDisciplinas == null");
    }
    this.cadastroDisciplinas = cadastroDisciplinas;
  }

  /**
   * Define cadastro de salas.
   * @param cadastroSalas
   */
  public void setCadastroSalas(ICadastroSalas cadastroSalas) throws
      IllegalArgumentException {

    if (cadastroSalas == null) {
      throw new IllegalArgumentException("cadastroSalas == null");
    }
    this.cadastroSalas = cadastroSalas;
  }

  /**
   * Define cadastro de horrios.
   * @param cadastroHorarios
   */
  public void setCadastroHorarios(ICadastroHorarios cadastroHorarios) throws
      IllegalArgumentException {

    if (cadastroHorarios == null) {
      throw new IllegalArgumentException("cadastroHorarios == null");
    }
    this.cadastroHorarios = cadastroHorarios;
  }

  /**
   * Define cadastro de horrios.
   * @param cadastroHorarios
   */
  public void setAlocacaoNegocio(IAlocacaoNegocio alocacaoNegocio) throws
      IllegalArgumentException {

    if (alocacaoNegocio == null) {
      throw new IllegalArgumentException("alocacaoNegocio == null");
    }
    this.alocacaoNegocio = alocacaoNegocio;
  }

/*****************************************************************************
 *** CadastroDeProfessores ***************************************************
 *****************************************************************************/

  /*
   * Insere professor no sistema.
   * @param nome
   * @param area
   */
  public void inserirProfessor(String nome, String area) throws
      SIAlocacaoException {

    this.cadastroProfessores.inserirProfessor(nome, area);
  }

  /*
   * Altera professor no sistema.
   * @param professor
   */
  public void alterarProfessor(Professor professor) throws SIAlocacaoException,
      ProfessorInexistenteException {

    this.cadastroProfessores.alterarProfessor(professor);
  }

  /*
   * Exclui professor do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirProfessor(int codigo) throws SIAlocacaoException,
      ProfessorInexistenteException {

    this.cadastroProfessores.excluirProfessor(codigo);
  }

  /*
   * Busca professor no sistema pelo cdigo.
   * @param codigo
   * @return Professor
   */
  public Professor buscarProfessor(int codigo) throws SIAlocacaoException {

    return this.cadastroProfessores.buscarProfessor(codigo);
  }

  /*
   * Busca professor no sistema pelo cdigo.
   * @param nome
   * @return Professor
   */
  public Professor buscarProfessor(String nome) throws SIAlocacaoException {

    return this.cadastroProfessores.buscarProfessor(nome);
  }

  /*
   * Lista professores do sistema.
   * @return ArrayList
   */
  public ArrayList listarProfessores() throws SIAlocacaoException {

    return this.cadastroProfessores.listarProfessores();
  }


/*****************************************************************************
 *** CadastroDeDisciplinas ***************************************************
 *****************************************************************************/

  /*
   * Insere disciplina no sistema.
   * @param descricao
   * @param cargaHoraria
   * @param ementa
   * @param area
   */
  public void inserirDisciplina(String descricao, int cargaHoraria, String ementa, String area)
      throws SIAlocacaoException {

    this.cadastroDisciplinas.inserirDisciplina(descricao, cargaHoraria, ementa, area);
  }

  /*
   * Altera disciplina no sistema.
   * @param disciplina
   */
  public void alterarDisciplina(Disciplina disciplina)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    this.cadastroDisciplinas.alterarDisciplina(disciplina);
  }

  /*
   * Exclui disciplina do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirDisciplina(int codigo)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    this.cadastroDisciplinas.excluirDisciplina(codigo);
  }

  /*
   * Busca disciplina no sistema pelo cdigo.
   * @param codigo
   * @return Disciplina
   */
  public Disciplina buscarDisciplina(int codigo)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    return this.cadastroDisciplinas.buscarDisciplina(codigo);
  }

  /*
   * Busca disciplina no sistema pela descricao.
   * @param descricao
   * @return Disciplina
   */
  public Disciplina buscarDisciplina(String descricao)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    return this.cadastroDisciplinas.buscarDisciplina(descricao);
  }

  /*
   * Lista disciplinas do sistema.
   * @return ArrayList
   */
  public ArrayList listarDisciplinas() throws
      SIAlocacaoException, DisciplinaInexistenteException {

    return this.cadastroDisciplinas.listarDisciplinas();
  }


/*****************************************************************************
 *** CadastroDeSalas *********************************************************
 *****************************************************************************/

  /*
   * Insere sala no sistema.
   * @param descricao
   * @param localizacao
   * @param observacao
   */
  public void inserirSala(String descricao, String localizacao, String observacao)
      throws SIAlocacaoException {

    this.cadastroSalas.inserirSala(descricao, localizacao, observacao);
  }

  /*
   * Altera sala no sistema.
   * @param sala
   */
  public void alterarSala(Sala sala) throws SIAlocacaoException,
      SalaInexistenteException {

    this.cadastroSalas.alterarSala(sala);
  }

  /*
   * Exclui sala do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirSala(int codigo) throws SIAlocacaoException,
      SalaInexistenteException {

    this.cadastroSalas.excluirSala(codigo);
  }

  /*
   * Busca sala no sistema pelo cdigo.
   * @param codigo
   * @return Sala
   */
  public Sala buscarSala(int codigo) throws SIAlocacaoException {

    return this.cadastroSalas.buscarSala(codigo);
  }

  /*
   * Busca sala no sistema pelo cdigo.
   * @param descricao
   * @return Sala
   */
  public Sala buscarSala(String descricao) throws SIAlocacaoException {

    return this.cadastroSalas.buscarSala(descricao);
  }

  /*
   * Lista salas do sistema.
   * @return ArrayList
   */
  public ArrayList listarSalas() throws SIAlocacaoException {

    return this.cadastroSalas.listarSalas();
  }

/*****************************************************************************
 *** CadastroDeHorarios ******************************************************
 *****************************************************************************/

  /*
   * Insere horrio no sistema.
   * @param diaDaSemana
   * @param horaInicio
   * @param horaFim
   */
  public void inserirHorario(String diaDaSemana, String horaInicio, String horaFim)
      throws SIAlocacaoException {

    this.cadastroHorarios.inserirHorario(diaDaSemana, horaInicio, horaFim);
  }

  /*
   * Altera horrio no sistema.
   * @param horario
   */
  public void alterarHorario(Horario horario) throws SIAlocacaoException,
      HorarioInexistenteException {

    this.cadastroHorarios.alterarHorario(horario);
  }

  /*
   * Exclui horrio do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirHorario(int codigo) throws SIAlocacaoException,
      HorarioInexistenteException {

    this.cadastroHorarios.excluirHorario(codigo);
  }

  /*
   * Busca horrio no sistema pelo cdigo.
   * @param codigo
   * @return Horario
   */
  public Horario buscarHorario(int codigo) throws SIAlocacaoException,
      HorarioInexistenteException {

    return this.cadastroHorarios.buscarHorario(codigo);
  }

  /*
   * Busca horrio no sistema pelo cdigo.
   * @param diaDaSemana
   * @param horaInicio
   * @param horaFim
   * @return Horario
   */
  public Horario buscarHorario(String diaDaSemana, String horaInicio,
    String horaFim) throws SIAlocacaoException {

    return this.cadastroHorarios.buscarHorario(diaDaSemana, horaInicio,
      horaFim);
  }

  /*
   * Lista horrios do sistema.
   * @return ArrayList
   */
  public ArrayList listarHorarios() throws SIAlocacaoException,
      HorarioInexistenteException {

    return this.cadastroHorarios.listarHorarios();
  }

  /*
   * Lista horrios do sistema.
   * @return ArrayList
   */
  public ArrayList listarHorariosDistintos() throws SIAlocacaoException,
      HorarioInexistenteException {

    return this.cadastroHorarios.listarHorarios();
  }

/******************************************************************************
 *** Alocacao *****************************************************************
 ******************************************************************************/

 /*
   * Insere uma Alocacao no sistema.
   * @param horario
   * @param sala
   * @param disciplina
   * @param professor
   */
  public void alocar(Horario horario, Sala sala, Disciplina disciplina, Professor professor) throws
      SIAlocacaoException{
    this.alocacaoNegocio.alocar(horario, sala, disciplina, professor);
  }

  /*
   * Retorna um objeto disciplina contendo as informaoes da disciplina alocada
   * no horario e sala especificados.
   * @param horario
   * @return sala
   */
  public Disciplina getDisciplinaAlocada(Horario horario, Sala sala)
      throws SIAlocacaoException{
    return this.alocacaoNegocio.getDisciplinaAlocada(horario, sala);
  }

  /*
   * Exclui Alocacao do sistema.
   * @param alocacao
   */
  public void excluirAlocacao(int codigo) throws SIAlocacaoException{
    this.alocacaoNegocio.excluirAlocacao(codigo);
  }

  /*
   * Altera Alocacao no sistema.
   * @param alocacao
   */
  public void alterarAlocacao(Alocacao alocacao)
      throws SIAlocacaoException, AlocacaoInexistenteException{
    this.alocacaoNegocio.alterarAlocacao(alocacao);
  }

  /*
   * Lista alocacoes do sistema.
   * @return ArrayList
   */
  public ArrayList listarAlocacoes() throws SIAlocacaoException{
    return this.alocacaoNegocio.listarAlocacoes();
  }


  /*
   * Retorna o objeto alocacao para horario e sala especificados.
   * @param horario
   * @return sala
   */
  public Alocacao getAlocacao(Horario horario, Sala sala) throws SIAlocacaoException,
      HorarioNaoAlocadoException{
    return this.alocacaoNegocio.getAlocacao(horario, sala);
  }
}