package sialocacao.disciplina.negocio;

/**
 * <p>Title: CadastroDisciplinas.java </p>
 * <p>Description: Implementa a camanda de negcio de disciplinas. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.*;
import sialocacao.disciplina.*;
import sialocacao.disciplina.database.*;
import sialocacao.disciplina.excecoes.*;

public class CadastroDisciplinas implements ICadastroDisciplinas {

  /*
   * Instncia do repositrio de disciplinas.
   */
   private IDisciplinaDatabase disciplinaDatabase;

  /*
   * Construtor definindo o repositrio de disciplinas.
   * @param disciplinaDatabase
   */
   public CadastroDisciplinas() throws ClassNotFoundException{
     setDisciplinaDatabase(new DisciplinaDatabase());
   }

  /*
   * Construtor definindo o repositrio de disciplinas.
   * @param disciplinaDatabase
   */
   public CadastroDisciplinas(IDisciplinaDatabase disciplinaDatabase) {
     setDisciplinaDatabase(disciplinaDatabase);
   }

  /*
   * Define repositrio de disciplinas.
   * @param disciplinaDatabase
   */
   public void setDisciplinaDatabase(IDisciplinaDatabase disciplinaDatabase)
      throws IllegalArgumentException {

    if (disciplinaDatabase == null) {
      throw new IllegalAccessError("disciplinaDatabase == null");
    }

    this.disciplinaDatabase = disciplinaDatabase;
  }

  /*
   * Insere disciplina no sistema.
   * @param descricao
   * @param cargaHoraria
   * @param ementa
   * @param area
   */
  public void inserirDisciplina(String descricao, int cargaHoraria, String ementa, String area)
      throws SIAlocacaoException {

    disciplinaDatabase.inserirDisciplina(descricao, cargaHoraria, ementa, area);
  }

  /*
   * Altera disciplina no sistema.
   * @param disciplina
   */
  public void alterarDisciplina(Disciplina disciplina)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    disciplinaDatabase.alterarDisciplina(disciplina);
  }

  /*
   * Exclui disciplina do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirDisciplina(int codigo)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    disciplinaDatabase.excluirDisciplina(codigo);
  }

  /*
   * Busca disciplina no sistema pelo cdigo.
   * @param codigo
   * @return Disciplina
   */
  public Disciplina buscarDisciplina(int codigo)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    return disciplinaDatabase.buscarDisciplina(codigo);
  }

  /*
   * Busca disciplina no sistema pelo cdigo.
   * @param descricao
   * @return Disciplina
   */
  public Disciplina buscarDisciplina(String descricao)
      throws SIAlocacaoException, DisciplinaInexistenteException {

    return disciplinaDatabase.buscarDisciplina(descricao);
  }

  /*
   * Lista disciplinas do sistema.
   * @return ArrayList
   */
  public ArrayList listarDisciplinas() throws
      SIAlocacaoException, DisciplinaInexistenteException {

    return disciplinaDatabase.listarDisciplinas();
  }
}