package sialocacao.disciplina.negocio;

/**
 * <p>Title: ICadastroDisciplinas.java </p>
 * <p>Description: Interface da classe CadastroDisciplinas. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.*;
import sialocacao.disciplina.*;
import sialocacao.disciplina.database.*;
import sialocacao.disciplina.excecoes.*;

public interface ICadastroDisciplinas {

  /*
   * Define repositrio de disciplinas.
   * @param disciplinaDatabase
   */
  public void setDisciplinaDatabase(IDisciplinaDatabase disciplinaDatabase)
      throws IllegalArgumentException;

  /*
   * Insere disciplina no sistema.
   * @param descricao
   * @param cargaHoraria
   * @param ementa
   * @param area
   */
  public void inserirDisciplina(String descricao, int cargaHoraria, String ementa, String area)
      throws SIAlocacaoException;

  /*
   * Altera disciplina no sistema.
   * @param disciplina
   */
  public void alterarDisciplina(Disciplina disciplina)
      throws SIAlocacaoException, DisciplinaInexistenteException;

  /*
   * Exclui disciplina do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirDisciplina(int codigo)
      throws SIAlocacaoException, DisciplinaInexistenteException;

  /*
   * Busca disciplina no sistema pelo cdigo.
   * @param codigo
   * @return Disciplina
   */
  public Disciplina buscarDisciplina(int codigo)
      throws SIAlocacaoException, DisciplinaInexistenteException;

  /*
   * Busca disciplina no sistema pelo cdigo.
   * @param descricao
   * @return Disciplina
   */
  public Disciplina buscarDisciplina(String descricao)
      throws SIAlocacaoException, DisciplinaInexistenteException;

  /*
   * Lista disciplinas do sistema.
   * @return ArrayList
   */
  public ArrayList listarDisciplinas() throws
      SIAlocacaoException, DisciplinaInexistenteException;
}