package sialocacao.horario.excecoes;

/**
 * <p>Title: HorarioInexistenteException.java </p>
 * <p>Description: Responsvel por tratar exceo de horrio inexistente. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import sialocacao.*;
import sialocacao.horario.*;

public class HorarioInexistenteException extends SIAlocacaoException {

  /*
   * Construtor responsvel por definir o cdigo do horrio inexistente.
   */
  public HorarioInexistenteException(String descricao) {
    setDescription(descricao);
  }

  /*
   * Construtor responsvel por definir o cdigo do horrio inexistente.
   */
  public HorarioInexistenteException(int codHorario) {
    setDescription(getDescription(codHorario));
  }

  /*
   * Construtor responsvel por definir o horrio inexistente.
   */
  public HorarioInexistenteException(Horario horario)
      throws IllegalArgumentException {

    if (horario == null) {
      throw new IllegalArgumentException("horario == null");
    }

    setDescription(getDescription(horario.getCodigo()));
  }

  /*
   * Define descrio da exceo, passando o cdigo do horrio inexistente.
   * @param codDisciplina
   */
  private String getDescription(int codHorario) {
    StringBuffer description =
        new StringBuffer("Nao existe hoario com o codigo ");

    description.append(codHorario);

    return description.toString();
  }
}