package sialocacao.horario.negocio;

/**
 * <p>Title: CadastroHorarios.java </p>
 * <p>Description: Implementa a camanda de negcio de horrios. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.*;
import sialocacao.horario.*;
import sialocacao.horario.database.*;
import sialocacao.horario.excecoes.*;

public class CadastroHorarios implements ICadastroHorarios {

  /*
   * Instncia do repositrio de horarios.
   */
  private IHorarioDatabase horarioDatabase;

  /*
   * Construtor definindo o repositrio de horarios.
   *
   */
  public CadastroHorarios() throws ClassNotFoundException{
    setHorarioDatabase(new HorarioDatabase());
  }

  /*
   * Construtor definindo o repositrio de horarios.
   * @param horarioDatabase
   */
  public CadastroHorarios(IHorarioDatabase horarioDatabase) {
    setHorarioDatabase(horarioDatabase);
  }

  /*
   * Define repositrio de horarios.
   * @param horarioDatabase
   */
  public void setHorarioDatabase(IHorarioDatabase horarioDatabase) throws
      IllegalArgumentException {

    if (horarioDatabase == null) {
      throw new IllegalAccessError("salaDatabase == null");
    }

    this.horarioDatabase = horarioDatabase;
  }

  /*
   * Insere horrio no sistema.
   * @param diaDaSemana
   * @param horaInicio
   * @param horaFim
   */
  public void inserirHorario(String diaDaSemana, String horaInicio, String horaFim)
      throws SIAlocacaoException {

    this.horarioDatabase.inserirHorario(diaDaSemana, horaInicio, horaFim);
  }

  /*
   * Altera horrio no sistema.
   * @param horario
   */
  public void alterarHorario(Horario horario) throws SIAlocacaoException,
      HorarioInexistenteException {

    this.horarioDatabase.alterarHorario(horario);
  }

  /*
   * Exclui horrio do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirHorario(int codigo) throws SIAlocacaoException,
      HorarioInexistenteException {
    this.horarioDatabase.excluirHorario(codigo);
  }

  /*
   * Busca horrio no sistema pelo cdigo.
   * @param codigo
   * @return Horario
   */
  public Horario buscarHorario(int codigo) throws SIAlocacaoException {
    return this.horarioDatabase.buscarHorario(codigo);
  }

  /*
   * Busca horrio no sistema pelo cdigo.
   * @param diaDaSemana
   * @param horaInicio
   * @param horaFim
   * @return Horario
   */
  public Horario buscarHorario(String diaDaSemana, String horaInicio,
    String horaFim) throws SIAlocacaoException {
    return this.horarioDatabase.buscarHorario(diaDaSemana, horaInicio,
      horaFim);
  }

  /*
   * Lista horrios do sistema.
   * @return ArrayList
   */
  public ArrayList listarHorarios() throws SIAlocacaoException,
      HorarioInexistenteException {
    return this.horarioDatabase.listarHorarios();
  }

  /*
   * Lista horrios do sistema.
   * @return ArrayList
   */
  public ArrayList listarHorariosDistintos() throws SIAlocacaoException,
      HorarioInexistenteException {
    return this.horarioDatabase.listarHorariosDistintos();
  }
}