package sialocacao.sala.excecoes;

/**
 * <p>Title: SalaInexistenteException.java </p>
 * <p>Description: Responsvel por tratar exceo de sala inexistente. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import sialocacao.*;
import sialocacao.sala.*;

public class SalaInexistenteException extends SIAlocacaoException {

  /*
   * Construtor responsvel por definir o cdigo da sala inexistente.
   */
  public SalaInexistenteException(int codSala) {
    setDescription(getDescription(codSala));
  }

  /*
   * Construtor responsvel por definir a descricao da sala inexistente.
   */
  public SalaInexistenteException(String descricao) {
    setDescription(getDescription(descricao));
  }

  /*
   * Construtor responsvel por definir a sala inexistente.
   */
  public SalaInexistenteException(Sala sala) throws
      IllegalArgumentException {

    if (sala == null) {
      throw new IllegalArgumentException("sala == null");
    }

    setDescription(getDescription(sala.getCodigo()));
  }

  /*
   * Define descrio da exceo, passando o cdigo da sala inexistente.
   * @param codDisciplina
   */
  private String getDescription(int codSala) {
    StringBuffer description =
        new StringBuffer("Nao existe sala com o codigo ");

    description.append(codSala);

    return description.toString();
  }

  /*
   * Define descrio da exceo, passando a descricao da sala inexistente.
   * @param codDisciplina
   */
  private String getDescription(String descricao) {
    StringBuffer description =
        new StringBuffer("Nao existe sala com a descricao ");

    description.append(descricao);

    return description.toString();
  }
}