package sialocacao.sala.negocio;

/**
 * <p>Title: ICadastroSalas.java </p>
 * <p>Description: Interface da classe CadastroSalas. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.*;
import sialocacao.sala.*;
import sialocacao.sala.database.*;
import sialocacao.sala.excecoes.*;

public interface ICadastroSalas {

  /*
   * Define repositrio de salas.
   * @param salaDatabase
   */
  public void setSalaDatabase(ISalaDatabase salaDatabase) throws
      IllegalArgumentException;

  /*
   * Insere sala no sistema.
   * @param descricao
   * @param localizacao
   * @param observacao
   */
  public void inserirSala(String descricao, String localizacao,
    String observacao) throws SIAlocacaoException;

  /*
   * Altera sala no sistema.
   * @param sala
   */
  public void alterarSala(Sala sala) throws SIAlocacaoException,
      SalaInexistenteException;

  /*
   * Exclui sala do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirSala(int codigo) throws SIAlocacaoException,
      SalaInexistenteException;

  /*
   * Busca sala no sistema pelo cdigo.
   * @param codigo
   * @return Sala
   */
  public Sala buscarSala(int codigo) throws SIAlocacaoException,
      SalaInexistenteException;

  /*
   * Busca sala no sistema pelo cdigo.
   * @param descricao
   * @return Sala
   */
  public Sala buscarSala(String descricao) throws SIAlocacaoException,
      SalaInexistenteException;

  /*
   * Lista salas do sistema.
   * @return ArrayList
   */
  public ArrayList listarSalas() throws SIAlocacaoException;
}