package sialocacao.alocacao.database;

/**
 * <p>Title: AlocacaoDatabase.java </p>
 * <p>Description: Implementa a camada de persistncia de Alocacao.</p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.sql.*;
import java.util.*;

import sialocacao.*;
import sialocacao.alocacao.*;
import sialocacao.alocacao.excecoes.*;

import sialocacao.professor.*;
import sialocacao.disciplina.*;
import sialocacao.sala.*;
import sialocacao.horario.*;


public class AlocacaoDatabase extends Database implements IAlocacaoDatabase {

  /*
   * Construtor para carregar driver jdbc.
   */
  public AlocacaoDatabase() throws ClassNotFoundException {
    super();
  }

  /**
   * Construtor para definir driver, url, usurio e senha,
   * e carregar driver jdbc.
   */
  public AlocacaoDatabase(String driver, String url, String user, String password)
      throws ClassNotFoundException, IllegalArgumentException {

    super(driver, url, user, password);
  }

  /*
   * Insere uma Alocacao no sistema.
   * @param horario
   * @param sala
   * @param disciplina
   * @param professor
   */
  public void alocar(Horario horario, Sala sala, Disciplina disciplina, Professor professor) throws
      SIAlocacaoException {

    try {
      openConnection();

      PreparedStatement cmd =
          getConnection().prepareStatement("SELECT * FROM alocacao " +
                                           "WHERE codHorario=? AND (  " +
                                           "codProfessor=? OR codSala=? )" );

      cmd.setInt(1, horario.getCodigo());
      cmd.setInt(2, professor.getCodigo());
      cmd.setInt(3, sala.getCodigo());

      ResultSet result = cmd.executeQuery();

      if (result.next())
      {
        if(result.getInt("codProfessor") == professor.getCodigo())
        {
          throw new SIAlocacaoException("Professor j alocado no horario " +
                                        "selecionado");
        } else
        {
          throw new SIAlocacaoException("Sala j alocada no horario " +
                                        "selecionado");
        }
      }

      result.close();

      cmd = getConnection().prepareStatement("INSERT INTO alocacao (codHorario," +
                                             "codSala, codDisciplina, codProfessor)" +
                                             " VALUES (?, ?, ?, ?)");

      cmd.setInt(1, horario.getCodigo());
      cmd.setInt(2, sala.getCodigo());
      cmd.setInt(3, disciplina.getCodigo());
      cmd.setInt(4, professor.getCodigo());

      cmd.executeUpdate();

    } catch (Exception e) {
      throw new SIAlocacaoException(e.getMessage(), e);
    } finally {
      try {
        if (getConnection() != null) {
          commit();
          closeConnection();
        }
      } catch (Exception e) {System.out.println("\nnao fechei\n");
        throw new SIAlocacaoException(e.getMessage(), e);
      }
    }
  }

  /*
   * Retorna um objeto disciplina contendo as informaoes da disciplina alocada
   * no horario e sala especificados.
   * @param horario
   * @return sala
   */
  public Disciplina getDisciplinaAlocada(Horario horario, Sala sala) throws SIAlocacaoException {

    try {
      openConnection();
      PreparedStatement cmd =
          getConnection().prepareStatement("SELECT disciplina.codigo, descricao " +
                                           "FROM alocacao, disciplina " +
                                           "WHERE codHorario=? AND codSala=? " +
                                           "AND codDisciplina=disciplina.codigo");

      cmd.setInt(1, horario.getCodigo());
      cmd.setInt(2, sala.getCodigo());

      ResultSet result = cmd.executeQuery();

      Disciplina disciplina = null;

      if (result.next()) {
        disciplina = new Disciplina(result.getInt("codigo"), result.getString("descricao"));
      }

      return disciplina;
    } catch (Exception e) {
      throw new SIAlocacaoException(e.getMessage(), e);
    } finally {
      try {
        if (getConnection() != null) {
          commit();
          closeConnection();
        }
      } catch (Exception e) {System.out.println("\nnao fechei\n");
        throw new SIAlocacaoException(e.getMessage(), e);
      }
    }
  }


  /*
   * Retorna o objeto alocacao para horario e sala especificados.
   * @param horario
   * @return sala
   */
  public Alocacao getAlocacao(Horario horario, Sala sala) throws SIAlocacaoException,
      HorarioNaoAlocadoException {

    try {
      openConnection();
      PreparedStatement cmd =
          getConnection().prepareStatement("SELECT codigo, codProfessor, " +
                                           "codDisciplina FROM alocacao " +
                                           "WHERE codHorario=? AND codSala=? ");

      cmd.setInt(1, horario.getCodigo());
      cmd.setInt(2, sala.getCodigo());

      ResultSet result = cmd.executeQuery();

      Alocacao alocacao;

      if (result.next()) {
        alocacao = new Alocacao(result.getInt("codigo"),
                                result.getInt("codProfessor"),
                                sala.getCodigo(),
                                horario.getCodigo(),
                                result.getInt("codDisciplina"));
      } else {
        throw new HorarioNaoAlocadoException();
      }

      return alocacao;
    } catch (HorarioNaoAlocadoException e) {
      throw e;
    } catch (Exception e) {
      throw new SIAlocacaoException(e.getMessage(), e);
    } finally {
      try {
        if (getConnection() != null) {
          commit();
          closeConnection();
        }
      } catch (Exception e) {System.out.println("\nnao fechei\n");
        throw new SIAlocacaoException(e.getMessage(), e);
      }
    }
  }


  /*
   * Altera Alocacao no sistema.
   * @param alocacao
   */
  public void alterarAlocacao(Alocacao alocacao)
      throws SIAlocacaoException, AlocacaoInexistenteException {

    try {

      openConnection();

      PreparedStatement cmd =
          getConnection().prepareStatement("SELECT * FROM alocacao " +
                                           "WHERE codigo !=? AND codHorario=? "+
                                           "AND (codProfessor=? OR codSala=?)");

      cmd.setInt(1, alocacao.getCodigo());
      cmd.setInt(2, alocacao.getCodHorario());
      cmd.setInt(3, alocacao.getCodProfessor());
      cmd.setInt(4, alocacao.getCodSala());

      ResultSet result = cmd.executeQuery();

      if (result.next())
      {
        if(result.getInt("codProfessor") == alocacao.getCodProfessor())
        {
          throw new SIAlocacaoException("Professor j alocado no horario " +
                                        "selecionado");
        } else
        {
          throw new SIAlocacaoException("Sala j alocada no horario " +
                                        "selecionado");
        }
      }

      result.close();

      cmd = getConnection().prepareStatement( "UPDATE alocacao SET " +
                                              "codProfessor=?, codSala=?, " +
                                              "codHorario=?, codDisciplina=? " +
                                              "WHERE codigo=?");

      cmd.setInt(1, alocacao.getCodProfessor());
      cmd.setInt(2, alocacao.getCodSala());
      cmd.setInt(3, alocacao.getCodHorario());
      cmd.setInt(4, alocacao.getCodDisciplina());
      cmd.setInt(5, alocacao.getCodigo());

      int num = cmd.executeUpdate();

      if (num == 0) {
        throw new AlocacaoInexistenteException(alocacao.getCodigo());
      }

    } catch (AlocacaoInexistenteException e) {
      throw e;
    } catch (Exception e) {
      throw new SIAlocacaoException(e.getMessage(), e);
    } finally {
      try {
        if (getConnection() != null) {
          commit();
          closeConnection();
        }
      } catch (Exception e) {System.out.println("\nnao fechei\n");
        throw new SIAlocacaoException(e.getMessage(), e);
      }
    }

  }

 /*
   * Exclui Alocacao do sistema.
   * @param codigo
   */
  public void excluirAlocacao(int codigo)
      throws SIAlocacaoException, AlocacaoInexistenteException {

    try {
      openConnection();
      PreparedStatement cmd =
          getConnection().prepareStatement("DELETE FROM alocacao WHERE " +
                                           "codigo=?");

      cmd.setInt(1, codigo );

      int num = cmd.executeUpdate();

      if (num == 0) {
        throw new AlocacaoInexistenteException(codigo);
      }

    } catch (AlocacaoInexistenteException e) {
      throw e;
    } catch (Exception e) {
      throw new SIAlocacaoException(e.getMessage(), e);
    } finally {
      try {
        if (getConnection() != null) {
          commit();
          closeConnection();
        }
      } catch (Exception e) {System.out.println("\nnao fechei\n");
        throw new SIAlocacaoException(e.getMessage(), e);
      }
    }

  }

  /*
   * Lista alocacoes do sistema.
   * @return ArrayList
   */
  public ArrayList listarAlocacoes() throws SIAlocacaoException {

    try {
      openConnection();
      PreparedStatement cmd =
          getConnection().prepareStatement("SELECT * FROM alocacao");

      ResultSet result = cmd.executeQuery();

      ArrayList alocacoes = new ArrayList();

      while (result.next()) {
        alocacoes.add(new Alocacao (result.getInt("codigo"),
                                    result.getInt("codProfessor"),
                                    result.getInt("codHorario"),
                                    result.getInt("codSala"),
                                    result.getInt("codDisciplina")));
      }

      return alocacoes;

    } catch (Exception e) {
      throw new SIAlocacaoException(e.getMessage(), e);
    } finally {
      try {
        if (getConnection() != null) {
          commit();
          closeConnection();
        }
      } catch (Exception e) {System.out.println("\nnao fechei\n");
        throw new SIAlocacaoException(e.getMessage(), e);
      }
    }
  } // listarAlocacoes
}
