package sialocacao.alocacao.excecoes;

/**
 * <p>Title: AlocacaoInexistenteException.java </p>
 * <p>Description: Responsvel por tratar exceo de Alocacao inexistente. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import sialocacao.*;
import sialocacao.alocacao.*;


public class AlocacaoInexistenteException extends SIAlocacaoException{
  /*
   * Construtor responsvel por definir o cdigo da alocacao inexistente.
   */
  public AlocacaoInexistenteException(int codAlocacao) {
    setDescription(getDescription(codAlocacao));
  }

  /*
   * Construtor responsvel por definir a descricao da alocacao inexistente.
   */
  public AlocacaoInexistenteException(String descricao) {
    setDescription(getDescription(descricao));
  }

  /*
   * Construtor responsvel por definir a alocacao inexistente.
   */
  public AlocacaoInexistenteException(Alocacao alocacao)
      throws IllegalArgumentException {
    if (alocacao == null) {
      throw new IllegalArgumentException("alocacao == null");
    }
    setDescription(getDescription(alocacao.getCodigo()));
  }

  /*
   * Define descrio da exceo, passando o cdigo da alocacao inexistente.
   * @param codDisciplina
   */
  private String getDescription(int codAlocacao) {
    StringBuffer description = new StringBuffer( "Nao existe alocacao com o codigo ");

    description.append(codAlocacao);

    return description.toString();
  }

  /*
   * Define descrio da exceo, passando a descricao da alocacao inexistente.
   * @param codDisciplina
   */
  private String getDescription(String descricao) {
    StringBuffer description = new StringBuffer( "Nao existe alocacao com o codigo ");

    description.append(descricao);

    return description.toString();
  }
}