package sialocacao.alocacao.negocio;

/**
 * <p>Title: AlocacaoNegocio.java </p>
 * <p>Description: Implementa a camanda de negcio de alocacao. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.*;
import sialocacao.alocacao.*;
import sialocacao.alocacao.database.*;
import sialocacao.alocacao.excecoes.*;

import sialocacao.professor.*;
import sialocacao.disciplina.*;
import sialocacao.sala.*;
import sialocacao.horario.*;

import sialocacao.professor.negocio.*;
import sialocacao.disciplina.negocio.*;
import sialocacao.sala.negocio.*;
import sialocacao.horario.negocio.*;

import sialocacao.professor.excecoes.*;
import sialocacao.disciplina.excecoes.*;
import sialocacao.sala.excecoes.*;
import sialocacao.horario.excecoes.*;

public class AlocacaoNegocio implements IAlocacaoNegocio {

  /*
   * Instanica da Interface da camada de negcios de disciplinas.
   */
  private ICadastroDisciplinas cadastroDisciplinas;

  /*
   * Instanica da Interface da camada de negcios de professores.
   */
  private ICadastroProfessores cadastroProfessores;

  /*
   * Instanica da Interface da camada de negcios de salas.
   */
  private ICadastroSalas cadastroSalas;

  /*
   * Instanica da Interface da camada de negcios de horarios.
   */
  private ICadastroHorarios cadastroHorarios;

  /*
   * Instncia do repositrio de alocacoes.
   */
  private IAlocacaoDatabase alocacaoDatabase;

  /*
   * Construtor definindo o repositrio de alocacoes.
   * @param
   */
  public AlocacaoNegocio() throws ClassNotFoundException{
    setAlocacaoDatabase(new AlocacaoDatabase());
    setCadastroDisciplinas( new CadastroDisciplinas() );
    setCadastroProfessores   ( new CadastroProfessores() );
    setCadastroSalas( new CadastroSalas() );
    setCadastroHorarios ( new CadastroHorarios() );
  }

  /*
   * Construtor.
   * @param alocacaoDatabase
   * @param cadastroDisciplinas
   * @param cadastroProfessores
   * @param cadastroSalas
   * @param cadastroHorarios
   */
  public AlocacaoNegocio(IAlocacaoDatabase alocacaoDatabase,
                         ICadastroDisciplinas cadastroDisciplinas,
                         ICadastroProfessores cadastroProfessores,
                         ICadastroSalas cadastroSalas,
                         ICadastroHorarios cadastroHorarios) {
    setAlocacaoDatabase(alocacaoDatabase);
    setCadastroDisciplinas(  cadastroDisciplinas );
    setCadastroProfessores   (  cadastroProfessores );
    setCadastroSalas(  cadastroSalas );
    setCadastroHorarios (  cadastroHorarios );


   }

   /*
    * Define repositrio de alocacoes.
    * @param disciplinaDatabase
    */
   public void setAlocacaoDatabase(IAlocacaoDatabase alocacaoDatabase)
       throws IllegalArgumentException {

     if (alocacaoDatabase == null) {
       throw new IllegalAccessError("alocacaoDatabase == null");
     }

     this.alocacaoDatabase = alocacaoDatabase;
   }

   /*
    * Define instanica da interface da camada de negcios de disciplina.
    * @param disciplinaDatabase
    */
   public void setCadastroDisciplinas ( ICadastroDisciplinas cadastroDisciplinas )
       throws IllegalArgumentException {

     if (cadastroDisciplinas == null) {
       throw new IllegalAccessError("cadastroDisciplinas == null");
     }

     this.cadastroDisciplinas = cadastroDisciplinas;
   }

   /*
    * Define instanica da interface da camada de negcios de professor.
    * @param cadastroProfessores
    */
   public void setCadastroProfessores ( ICadastroProfessores cadastroProfessores )
       throws IllegalArgumentException {

     if (cadastroProfessores == null) {
       throw new IllegalAccessError("cadastroProfessores == null");
     }

     this.cadastroProfessores = cadastroProfessores;
   }

   /*
    * Define instanica da interface da camada de negcios de sala.
    * @param cadastroSalas
    */
   public void setCadastroSalas ( ICadastroSalas cadastroSalas )
       throws IllegalArgumentException {

     if (cadastroSalas == null) {
       throw new IllegalAccessError("cadastroSalas == null");
     }

     this.cadastroSalas = cadastroSalas;
   }

   /*
    * Define instanica da interface da camada de negcios de horario.
    * @param cadastroHorarios
    */
   public void setCadastroHorarios ( ICadastroHorarios cadastroHorarios )
       throws IllegalArgumentException {

     if (cadastroHorarios == null) {
       throw new IllegalAccessError("cadastroHorarios == null");
     }

     this.cadastroHorarios = cadastroHorarios;
   }

   /*
    * Insere uma Alocacao no sistema.
    * @param horario
    * @param sala
    * @param disciplina
    * @param professor
    */
   public void alocar(Horario horario, Sala sala, Disciplina disciplina, Professor professor) throws
       SIAlocacaoException {

     try{
       cadastroDisciplinas.buscarDisciplina(disciplina.getCodigo());
     } catch ( DisciplinaInexistenteException e ) {
       throw new SIAlocacaoException("Disciplina no cadastrada");
     }

     try{
       cadastroProfessores.buscarProfessor(professor.getCodigo());
     } catch ( ProfessorInexistenteException e ) {
       throw new SIAlocacaoException("Professor no cadastrado");
     }

     try{
       cadastroHorarios.buscarHorario(horario.getCodigo());
     } catch ( HorarioInexistenteException e ) {
       throw new SIAlocacaoException("Horrio no cadastrado");
     }

     try{
       cadastroSalas.buscarSala(sala.getCodigo());
     } catch ( SalaInexistenteException e ) {
       throw new SIAlocacaoException("Sala no cadastrada");
     }


     alocacaoDatabase.alocar(horario, sala, disciplina, professor);

   }

   /*
    * Retorna um objeto disciplina contendo as informaoes da disciplina alocada
    * no horario e sala especificados.
    * @param horario
    * @return sala
    */
   public Disciplina getDisciplinaAlocada(Horario horario, Sala sala)
       throws SIAlocacaoException{
     return alocacaoDatabase.getDisciplinaAlocada(horario,  sala);
   }

   /*
    * Exclui Alocacao do sistema.
    * @param alocacao
    */
   public void excluirAlocacao(int codigo) throws SIAlocacaoException{
     alocacaoDatabase.excluirAlocacao(codigo);
   }

   /*
    * Altera Alocacao no sistema.
    * @param alocacao
    */
   public void alterarAlocacao(Alocacao alocacao)
       throws SIAlocacaoException, AlocacaoInexistenteException
   {
     try{
       cadastroDisciplinas.buscarDisciplina(alocacao.getCodDisciplina());
     } catch ( DisciplinaInexistenteException e ) {
       throw new SIAlocacaoException("Disciplina no cadastrada");
     }

     try{
       cadastroProfessores.buscarProfessor(alocacao.getCodProfessor());
     } catch ( ProfessorInexistenteException e ) {
       throw new SIAlocacaoException("Professor no cadastrado");
     }

     try{
       cadastroHorarios.buscarHorario(alocacao.getCodHorario());
     } catch ( HorarioInexistenteException e ) {
       throw new SIAlocacaoException("Horrio no cadastrado");
     }

     try{
       cadastroSalas.buscarSala(alocacao.getCodSala());
     } catch ( SalaInexistenteException e ) {
       throw new SIAlocacaoException("Sala no cadastrada");
     }

     alocacaoDatabase.alterarAlocacao(alocacao);
   }

   /*
    * Lista alocacoes do sistema.
    * @return ArrayList
    */
   public ArrayList listarAlocacoes() throws SIAlocacaoException {
     return alocacaoDatabase.listarAlocacoes();
   }

   /*
    * Retorna o objeto alocacao para horario e sala especificados.
    * @param horario
    * @return sala
    */
   public Alocacao getAlocacao(Horario horario, Sala sala) throws SIAlocacaoException,
       HorarioNaoAlocadoException
   {
     return alocacaoDatabase.getAlocacao(horario, sala);
   }

}