package sialocacao.alocacao.negocio;

/**
 * <p>Title: IAlocacaoNegocios.java </p>
 * <p>Description: Interface da classe AlocacaoNegocios. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.*;
import sialocacao.alocacao.*;
import sialocacao.alocacao.database.*;
import sialocacao.alocacao.excecoes.*;

import sialocacao.professor.*;
import sialocacao.disciplina.*;
import sialocacao.sala.*;
import sialocacao.horario.*;

import sialocacao.professor.negocio.*;
import sialocacao.disciplina.negocio.*;
import sialocacao.sala.negocio.*;
import sialocacao.horario.negocio.*;

public interface IAlocacaoNegocio {

  /*
   * Define repositrio de alocacao.
   * @param disciplinaDatabase
   */
  public void setAlocacaoDatabase(IAlocacaoDatabase alocacaoDatabase)
      throws IllegalArgumentException;

  /*
   * Define instanica da interface da camada de negcios de disciplina.
   * @param disciplinaDatabase
   */
  public void setCadastroDisciplinas ( ICadastroDisciplinas cadastroDisciplinas )
      throws IllegalArgumentException ;

  /*
   * Define instanica da interface da camada de negcios de professor.
   * @param cadastroProfessores
   */
  public void setCadastroProfessores ( ICadastroProfessores cadastroProfessores )
      throws IllegalArgumentException ;

  /*
   * Define instanica da interface da camada de negcios de sala.
   * @param cadastroSalas
   */
  public void setCadastroSalas ( ICadastroSalas cadastroSalas )
      throws IllegalArgumentException ;

  /*
   * Define instanica da interface da camada de negcios de horario.
   * @param cadastroHorarios
   */
  public void setCadastroHorarios ( ICadastroHorarios cadastroHorarios )
      throws IllegalArgumentException;


  /*
   * Insere uma Alocacao no sistema.
   * @param horario
   * @param sala
   * @param disciplina
   * @param professor
   */
  public void alocar(Horario horario, Sala sala, Disciplina disciplina, Professor professor) throws
      SIAlocacaoException;

  /*
   * Retorna um objeto disciplina contendo as informaoes da disciplina alocada
   * no horario e sala especificados.
   * @param horario
   * @return sala
   */
  public Disciplina getDisciplinaAlocada(Horario horario, Sala sala)
      throws SIAlocacaoException;

  /*
   * Exclui Alocacao do sistema.
   * @param alocacao
   */
  public void excluirAlocacao(int codigo) throws SIAlocacaoException;

  /*
   * Altera Alocacao no sistema.
   * @param alocacao
   */
  public void alterarAlocacao(Alocacao alocacao)
      throws SIAlocacaoException, AlocacaoInexistenteException;

  /*
   * Lista alocacoes do sistema.
   * @return ArrayList
   */
  public ArrayList listarAlocacoes() throws SIAlocacaoException;


  /*
   * Retorna o objeto alocacao para horario e sala especificados.
   * @param horario
   * @return sala
   */
  public Alocacao getAlocacao(Horario horario, Sala sala) throws SIAlocacaoException,
      HorarioNaoAlocadoException;



}


