package sialocacao.professor.negocio;

/**
 * <p>Title: CadastroProfessores.java </p>
 * <p>Description: Implementa a camanda de negcio de professores. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */

import java.util.*;

import sialocacao.*;
import sialocacao.professor.*;
import sialocacao.professor.database.*;
import sialocacao.professor.excecoes.*;

public class CadastroProfessores implements ICadastroProfessores {

  /*
   * Instncia do repositrio de professores.
   */
  private IProfessorDatabase professorDatabase;

  /*
   * Construtor default definindo o repositrio de professores.
   *
   */
  public CadastroProfessores() throws ClassNotFoundException{
    setProfessorDatabase(new ProfessorDatabase());
  }

  /*
   * Construtor definindo o repositrio de professores.
   * @param professorDatabase
   */
  public CadastroProfessores(IProfessorDatabase professorDatabase) {
    setProfessorDatabase(professorDatabase);
  }

  /*
   * Define repositrio de professores.
   * @param professorDatabase
   */
  public void setProfessorDatabase(IProfessorDatabase professorDatabase) throws
      IllegalArgumentException {

    if (professorDatabase == null) {
      throw new IllegalAccessError("professorDatabase == null");
    }

    this.professorDatabase = professorDatabase;
  }

  /*
   * Insere professor no sistema.
   * @param nome
   * @param area
   */
  public void inserirProfessor(String nome, String area) throws
      SIAlocacaoException {

    professorDatabase.inserirProfessor(nome, area);
  }

  /*
   * Altera professor no sistema.
   * @param professor
   */
  public void alterarProfessor(Professor professor) throws SIAlocacaoException,
      ProfessorInexistenteException {

    professorDatabase.alterarProfessor(professor);
  }

  /*
   * Exclui professor do sistema pelo cdigo.
   * @param codigo
   */
  public void excluirProfessor(int codigo) throws SIAlocacaoException,
      ProfessorInexistenteException {

    professorDatabase.excluirProfessor(codigo);
  }

   /*
   * Busca professor no sistema pelo cdigo.
   * @param codigo
   * @return Professor
   */
  public Professor buscarProfessor(int codigo) throws SIAlocacaoException,
      ProfessorInexistenteException {

    return professorDatabase.buscarProfessor(codigo);
  }

  /*
   * Busca professor no sistema pelo cdigo.
   * @param nome
   * @return Professor
   */
  public Professor buscarProfessor(String nome) throws SIAlocacaoException,
      ProfessorInexistenteException {

    return professorDatabase.buscarProfessor(nome);
  }

  /*
   * Lista professores do sistema.
   * @return ArrayList
   */
  public ArrayList listarProfessores() throws SIAlocacaoException {

    return professorDatabase.listarProfessores();
  }
}